@@ -11,6 +11,19 @@ from docarray.array.storage.base.helper import Offset2ID
 from docarray import Document, DocumentArray
 
 
+def _check_valid_values_nested_set(docs, values):
+    docs, values = DocumentArray(docs), DocumentArray(values)
+    if len(docs) != len(values):
+        raise ValueError(
+            f'length of docs to set({len(docs)}) does not match '
+            f'length of values({len(values)})'
+        )
+    if docs[:, 'id'] != values[:, 'id']:
+        raise ValueError(
+            'Setting Documents by traversal paths with different IDs is not supported'
+        )
+
+
 class BaseGetSetDelMixin(ABC):
     """Provide abstract methods and derived methods for ``__getitem__``, ``__setitem__`` and ``__delitem__``
 
@@ -128,10 +141,12 @@ class BaseGetSetDelMixin(ABC):
             self._del_doc_by_id(_id)
 
     def _update_subindices_del(self, ids):
+        if isinstance(ids, str) and ids.startswith('@'):
+            return  # deleting via access path is not supported
         if getattr(self, '_subindices', None):
             for selector, da in self._subindices.items():
                 ids_subindex = DocumentArray(self[ids])[selector, 'id']
-                da._del_docs_by_ids(ids_subindex)
+                del da[ids_subindex]
 
     def _del_docs(self, ids):
         self._del_docs_by_ids(ids)
@@ -173,15 +188,26 @@ class BaseGetSetDelMixin(ABC):
         for _id, doc in zip(ids, docs):
             self._set_doc_by_id(_id, doc)
 
-    def _update_subindices_set(self, ids, docs):
-        if getattr(self, '_subindices', None):
-            for selector, da in self._subindices.items():
-                old_ids = DocumentArray(self[ids])[
-                    selector, 'id'
-                ]  # hack to get the Document['@c'] without having to do Document.chunks
-                with da:
-                    del da[old_ids]
-                    da.extend(DocumentArray(docs)[selector])  # same hack here
+    def _update_subindices_set(self, set_index, docs):
+        subindices = getattr(self, '_subindices', None)
+        if not subindices:
+            return
+        if isinstance(set_index, tuple):  # handled later in recursive call
+            return
+        if isinstance(set_index, str) and set_index.startswith('@'):
+            # 'nested' (non root-level) set, update entire subindex directly
+            _check_valid_values_nested_set(self[set_index], docs)
+            if set_index in subindices:
+                subindex_da = subindices[set_index]
+                with subindex_da:
+                    subindex_da.clear()
+                    subindex_da.extend(docs)
+        else:  # root level set, update subindices iteratively
+            for subindex_selector, subindex_da in subindices.items():
+                old_ids = DocumentArray(self[set_index])[subindex_selector, 'id']
+                with subindex_da:
+                    del subindex_da[old_ids]
+                    subindex_da.extend(DocumentArray(docs)[subindex_selector])
 
     def _set_docs(self, ids, docs: Iterable['Document']):
         docs = list(docs)
@@ -228,17 +254,9 @@ class BaseGetSetDelMixin(ABC):
         :param values: the value docs will be updated to
         """
         docs = list(docs)
-        if len(docs) != len(values):
-            raise ValueError(
-                f'length of docs to set({len(docs)}) does not match '
-                f'length of values({len(values)})'
-            )
+        _check_valid_values_nested_set(docs, values)
 
         for _d, _v in zip(docs, values):
-            if _d.id != _v.id:
-                raise ValueError(
-                    'Setting Documents by traversal paths with different IDs is not supported'
-                )
             _d._data = _v._data
             if _d not in self:
                 root_d = self._find_root_doc_and_modify(_d)
